#include <stdint.h>
#include "accel3.h"
#include "resources.h"

sbit ACCEL_3_CS  at GPIOD_ODR.B13;
sbit ACCEL_3_INT at GPIOD_IDR.B10;
sbit ACCEL_3_RST at GPIOC_ODR.B2;



uint8_t command = 0x31;
uint8_t buffer;
uint8_t int_flag = 0;

void system_setup( uint8_t address, accel_mode_t accel_mode,
                   data_rate_t d_rate, bus_mode_t mode );
void accel3_interrupt_setup( void );

void main()
{
  uint8_t address = 0x18;
  xyz_t* my_coords;
  char text[50];

  DisableInterrupts();
  RCC_APB2ENR.AFIOEN = 1;              // Enable clock for alternate pin functions
  AFIO_EXTICR3 = 0x0300;               // PD10 as External interrupt
  EXTI_RTSR = 0x00000400;              // Set interrupt on Falling edge
  EXTI_IMR |= 0x00000400;              // Set mask
  NVIC_IntEnable(IVT_INT_EXTI15_10);   // Enable External interrupt                                                                                                                                                         */
  EnableInterrupts();                  // Enables the processor interrupt.

  system_setup( address, NORMAL, HZ_100, SPI_bus );

  accel3_interrupt_setup();
  accel3_hp_filter_mode_select( HP_NORMAL_MODE );
  accel3_filtered_data_selection_enable( true );

  while (1)
  {
    	 
	 if( accel3_is_new_data_all() )
	 {
		 my_coords = accel3_get_xyz_raw();
         sprintf( text, " x: %d y: %d z: %d ", my_coords->x_pos, my_coords->y_pos, my_coords->z_pos );
         UART1_Write_Text( text );
         UART1_Write_Text( "\r\n" );

		 Delay_ms(10);
	 }

    /*if ( int_flag == 1 )
    {
      int_flag = 0;
      UART1_Write_Text( "INT" );
      UART1_Write_Text( "\r\n" );

      GPIOE_ODR = ~GPIOE_ODR; // Toggle PORTE
      Delay_ms(400);
    }
    Delay_ms(30);
    accel3_is_z_low_interrupt1();   */
  }

}

void accel3_interrupt_setup( void )
{
  uint8_t thresh = 5;
  uint8_t duration = 1;

  //Set Accel 3 to interrupt when tapped
  accel3_set_interrupt1( thresh, duration );
  accel3_int1_signal_config( INT1_SOURCE );
  accel3_interrupt_active_level( LOW );
  accel3_interrupt_pad_selection( PUSH_PULL );
  accel3_interrupt1_set_combination( OR );
  accel3_interrupt1_x_high_enable( false );
  accel3_interrupt1_x_low_enable( false );
  accel3_interrupt1_y_high_enable( false );
  accel3_interrupt1_y_low_enable( false );
  accel3_interrupt1_z_high_enable( true );
  accel3_interrupt1_z_low_enable( false );
  accel3_latched_interrupt1_enable( true );


}

void accell_ISR() iv IVT_INT_EXTI15_10 ics ICS_AUTO
{

  int_flag = 1;
  EXTI_PR.B10 = 1;                     // clear flag

}

void system_setup( uint8_t address, accel_mode_t accel_mode,
                   data_rate_t d_rate, bus_mode_t mode )
{

  //GPIO Outputs
  GPIO_Digital_Output( &GPIOD_BASE, _GPIO_PINMASK_13 );
  GPIO_Digital_Input( &GPIOD_BASE, _GPIO_PINMASK_10 );
  GPIO_Digital_Output(&GPIOE_BASE, _GPIO_PINMASK_ALL); // Set PORTE as digital output
  Delay_ms(200);


  ACCEL_3_INT = 1;

  ACCEL_3_RST = 0;
  Delay_ms(10);
  ACCEL_3_RST = 1;

  GPIOE_ODR = 0;

  //I2C  or  SPI
 // I2C1_Init_Advanced( 100000, &_GPIO_MODULE_I2C1_PB67 );
  Delay_ms(200);
  SPI3_Init_Advanced( _SPI_FPCLK_DIV4,
                          _SPI_MASTER | _SPI_8_BIT | _SPI_CLK_IDLE_LOW |
                          _SPI_FIRST_CLK_EDGE_TRANSITION | _SPI_MSB_FIRST |
                          _SPI_SS_DISABLE | _SPI_SSM_ENABLE |
                          _SPI_SSI_1,
                          &_GPIO_MODULE_SPI3_PC10_11_12 );

  Delay_ms( 200 );

  //Accel 3 Initialization
  accel3_init( address, NORMAL, HZ_100, mode );


  //UART Initialization
  UART1_Init(9600);
  Delay_ms(200);
  UART1_Write_Text( "UART Initialized" );
  UART1_Write_Text( "\r\n" );

}
